@@ -1,6 +1,6 @@
 /*
  * Pike Extension Modules - A collection of modules for the Pike Language
- * Copyright  2000, 2001 The Caudium Group
+ * Copyright  2000-2003 The Caudium Group
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
 #ifdef HAVE_BDB
 #include <db.h>
 
-#define BDB ((BDB_Storage *)fp->current_storage)
+#define BDB ((BDB_Storage *)Pike_fp->current_storage)
 #define BDBERR( msg) Pike_error("%s\n", msg)
 #define CHECKBDB() DB *db; DB_TXN *txnid; if(!(BDB->state)) BDBERR("Database not initialized."); else if((BDB->state) == -1) BDBERR("Database is closed."); db = BDB->db; txnid = BDB->txnid;
 typedef struct
