@@ -1,6 +1,6 @@
 /*
  * Pike Extension Modules - A collection of modules for the Pike Language
- * Copyright  2000-2002 The Caudium Group
+ * Copyright  2000-2003 The Caudium Group
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,10 +15,54 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * $Id: fdf_main.c,v 1.10 2003/02/19 02:11:23 grendel Exp $
+ */
+
+/*
+ * File licensing and authorship information block.
+ *
+ * Version: MPL 1.1/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Initial Developer of the Original Code is
+ *
+ * Marek Habersack <grendel@caudium.net>
+ *
+ * Portions created by the Initial Developer are Copyright (C) Marek Habersack
+ * & The Caudium Group. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of the LGPL, and not to allow others to use your version
+ * of this file under the terms of the MPL, indicate your decision by
+ * deleting the provisions above and replace them with the notice
+ * and other provisions required by the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL or the LGPL.
+ *
+ * Significant Contributors to this file are:
+ *
+ */
+
+/*
  *
  * Glue for the Adobe FDF SDK
  *
- * $Id: fdf_main.c,v 1.4 2002/01/28 12:43:17 grendel Exp $
+ * $Id: fdf_main.c,v 1.10 2003/02/19 02:11:23 grendel Exp $
  */
 
 /*! @module _FDF
@@ -29,7 +73,7 @@
 #endif
 
 #include "global.h"
-RCSID("$Id: fdf_main.c,v 1.4 2002/01/28 12:43:17 grendel Exp $");
+RCSID("$Id: fdf_main.c,v 1.10 2003/02/19 02:11:23 grendel Exp $");
 
 #include "caudium_util.h"
 #include "fdf_config.h"
@@ -55,7 +99,7 @@ typedef struct
 #endif
 } FDF_STORAGE;
 
-#define THIS ((FDF_STORAGE*)get_storage(fp->current_object, fdf_program))
+#define THIS ((FDF_STORAGE*)get_storage(Pike_fp->current_object, fdf_program))
 #define THAT(X) ((FDF_STORAGE*)get_storage((X), (X)->prog))
 
 /* pdfFileSpec stuff */
@@ -425,7 +469,7 @@ static void f_FDFSetOnImportJavaScript(INT32 args)
 {
     FDFErc   ret;
     char    *script = NULL;
-    ASBool   before = 0;
+    INT32   before = 0;
     
     get_all_args("FDF->SetOnImportJavaScript", args, "%s%i", &script, &before);
 
@@ -485,7 +529,7 @@ static ASBool enumValuesProc(char *fieldName, char *fieldVal, void *data)
 static void f_FDFEnumValues(INT32 args)
 {
     FDFErc          ret;
-    ASBool          skipEmpty = 0;
+    INT32          skipEmpty = 0;
     char           *nameBuf;
     char           *valueBuf;
     unsigned        memamt = 0;
@@ -678,7 +722,7 @@ static void f_FDFExtractAttachment(INT32 args)
 #define BUF_SIZE 1024
     
     FDFErc          ret;
-    ASBool          isFilePath = 0;
+    INT32          isFilePath = 0;
     char           *path = NULL, *fieldName = NULL, *mimeType = NULL;
     ASInt32         nFileName, nMimeTypeSize;
     struct mapping *m;
@@ -1551,7 +1595,7 @@ static void f_FDFSetGoToAction(INT32 args)
     FDFErc            ret;
     char             *field, *dest;
     FDFActionTrigger  which;
-    ASBool            notUsed = 0;
+    INT32            notUsed = 0;
 
     switch(args) {
         case 3:
@@ -1592,7 +1636,7 @@ static void f_FDFSetGoToRAction(INT32 args)
     FDFErc            ret;
     char             *field, *dest, *theFile;
     FDFActionTrigger  which;
-    ASBool            addNewWindow = 0, newWindow = 1, notUsed = 0;
+    INT32            addNewWindow = 0, newWindow = 1, notUsed = 0;
 
     switch(args) {
         case 3:
@@ -1645,7 +1689,7 @@ static void f_FDFSetHideAction(INT32 args)
     FDFErc            ret;
     char             *field, *dest;
     FDFActionTrigger  which;
-    ASBool            isHide = 1;
+    INT32            isHide = 1;
 
     switch(args) {
         case 3:
@@ -1686,7 +1730,7 @@ static void f_FDFSetIF(INT32 args)
     FDFErc            ret;
     char             *field;
     FDFScaleWhen      scaleWhen;
-    ASBool            proportional = 0;
+    INT32            proportional = 0;
     float             x, y;
 
     get_all_args("FDF->SetIF", args, "%s%i%i%f%f", &field, &scaleWhen,
@@ -2039,7 +2083,7 @@ static void f_FDFSetURIAction(INT32 args)
     FDFErc            ret;
     char             *field, *uri;
     FDFActionTrigger  which;    
-    ASBool            isMap;
+    INT32            isMap;
     
     get_all_args("FDF->SetURIAction", args, "%s%i%s%i", &field, &which, &uri, &isMap);
 
@@ -2068,7 +2112,7 @@ static void f_FDFSetValue(INT32 args)
 {
     FDFErc            ret;
     char             *field, *val;
-    ASBool            notUsed;
+    INT32            notUsed;
     
     get_all_args("FDF->SetValue", args, "%s%s%i", &field, &val, &notUsed);
 
@@ -2234,6 +2278,9 @@ static void f_errname(INT32 args)
 /* Pike interface */
 static void init_fdf(struct object *o)
 {
+    if (!THIS)
+        return;
+    
     THIS->theFDF = NULL;
 #ifdef PIKE_THREADS
     mt_init(&THIS->mutex);
@@ -2242,6 +2289,9 @@ static void init_fdf(struct object *o)
 
 static void exit_fdf(struct object *o)
 {
+    if (!THIS)
+        return;
+    
 #ifdef PIKE_THREADS
     mt_destroy(&THIS->mutex);
 #endif
