@@ -1,6 +1,6 @@
 /*
  * Pike Extension Modules - A collection of modules for the Pike Language
- * Copyright  2000, 2001 The Caudium Group
+ * Copyright  2000-2003 The Caudium Group
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,24 +16,60 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Glue for the bzip2 compression library v1.0.x
- *
- * $Id: gpgme_main.c,v 1.5 2002/03/22 03:48:16 grendel Exp $
+ * $Id: gpgme_main.c,v 1.12 2003/02/19 02:11:25 grendel Exp $
  */
+
+/*
+ * File licensing and authorship information block.
+ *
+ * Version: MPL 1.1/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Initial Developer of the Original Code is
+ *
+ * Marek Habersack <grendel@caudium.net>
+ *
+ * Portions created by the Initial Developer are Copyright (C) Marek Habersack
+ * & The Caudium Group. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of the LGPL, and not to allow others to use your version
+ * of this file under the terms of the MPL, indicate your decision by
+ * deleting the provisions above and replace them with the notice
+ * and other provisions required by the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL or the LGPL.
+ *
+ * Significant Contributors to this file are:
+ *
+ */
+
 #define _GNU_SOURCE
 
 #include <stdio.h>
 
 #include "global.h"
-RCSID("$Id: gpgme_main.c,v 1.5 2002/03/22 03:48:16 grendel Exp $");
+RCSID("$Id: gpgme_main.c,v 1.12 2003/02/19 02:11:25 grendel Exp $");
 
 #include "gpgme_config.h"
 
-#ifdef HAVE_LIBGPGME
-
 #ifdef HAVE_GPGME_H
+
 #include <gpgme.h>
-#endif
 
 #include "caudium_util.h"
 
@@ -51,7 +87,7 @@ typedef struct
     const char        *gver;
 } GPGME_STRUCT;
 
-#define THIS ((GPGME_STRUCT*)get_storage(fp->current_object, gpgme_program))
+#define THIS ((GPGME_STRUCT*)get_storage(Pike_fp->current_object, gpgme_program))
 #define CHECK_OK if (!THIS->ev_ok) {pop_n_elems(args); push_int(GPGME_Invalid_Engine); return; }
 
 
